#!/usr/bin/python
# -*- coding: utf-8 -*-
"""Setup file for aquiline.

This is the setup file for the aquiline master package. It includes some sub
components which may or may not be split up into sub packages at a later date.
"""
# Copyright (C) 2008-2010  James Shubin, McGill University
# Written for McGill University by James Shubin <purpleidea@gmail.com>
#
# This program is free software: you can redistribute it and/or modify
# it under the terms of the GNU Affero General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU Affero General Public License for more details.
#
# You should have received a copy of the GNU Affero General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.

import os			# for path manipulation stuff
import sys			# for sys.modules
import pydoc
import distutils.core		#from distutils.core import setup, Extension
from jhelp import misc		# for get_version, get_capitalized_files
from jhelp import uninstall	# custom distutils uninstall & install commands
from src import prefix		# used to find the name of this project

# VARIABLES ###################################################################
NAME = prefix.name('src')		# should be the name of this dir
# this pulls the one-line description and long description from the docstring
DESCRIPTION, LDESCRIPTION = pydoc.splitdoc(pydoc.getdoc(sys.modules[__name__]))

# SETUP #######################################################################
distutils.core.setup(
	name=NAME,
	version=misc.get_version(),
	author='James Shubin',
	author_email='purpleidea@gmail.com',
	url='http://www.cs.mcgill.ca/~james/code/',
	description=DESCRIPTION,
	long_description=LDESCRIPTION,
	# http://pypi.python.org/pypi?%3Aaction=list_classifiers
	classifiers=[
		'Environment :: Console',
		'Intended Audience :: System Administrators',
		'License :: OSI Approved :: GNU Affero General Public License v3',
		'Topic :: Software Development :: Libraries',
		'Topic :: System :: Systems Administration',
	],
	packages=[NAME],
	package_dir={NAME:'src'},
	data_files = [
		('/usr/share/dbus-1/services/', ['files/ca.mcgill.cs.dazzle.free.server.service']),
		('/etc/dbus-1/system.d/', ['files/ca.mcgill.cs.dazzle.free.server.conf']),
		('share/%s' % NAME, ['files/gportalrc.conf']),
		('share/%s' % NAME, ['Makefile']),
		('share/%s' % NAME, misc.get_capitalized_files()),
		('share/%s/examples' % NAME, ['examples/_fixpath.py']),
		('share/%s/examples' % NAME, ['examples/g_dbus_server_example.py']),
	],
	scripts=['gportal'],
	cmdclass={
		'install': uninstall.install, 'uninstall': uninstall.uninstall
	}
)

